#
# Spec file for OCFS2 on EL4
#

# Macros
# This one is hardcoded because, well, it belongs there
%define _prefix /usr
# Because RPM is dumb
%define _unpackaged_files_terminate_build 0

# Turn ons and offs
%define buildup		1
%define buildsmp	0
%define buildhugemem	0
%define buildlargesmp	0

%ifarch i686
%define karch		i686
%define buildsmp	1
%define buildhugemem	1
%endif

%ifarch x86_64
%define karch		x86_64
%define buildsmp	1
%define buildlargesmp	1
%endif

%ifarch ia64
%define karch		ia64
%define buildlargesmp	1
%endif

%ifarch ppc64
%define karch		ppc64
%define buildlargesmp	1
%endif

%ifarch s390x
%define karch		s390x
%endif

%define kver		2.6.9-42.0.0.0.1.EL

# The minimum tools package required for the kernel bits.
%define tools_ver     1.1.1

Summary: The Oracle Cluster Filesystem 2.
Name: ocfs2-%{kver}
Version: 1.2.3
Release: 2
Copyright: GPL
Group: System Environment/Kernel
Source: ocfs2-1.2.3.tar.gz
URL: http://oss.oracle.com/projects/ocfs2/
Distribution: Oracle
Vendor: Oracle
Packager: Joel Becker <joel.becker@oracle.com>
Provides: ocfs2 = %{version}
AutoReqProv: no
Requires: kernel = %{kver}
Requires: ocfs2-tools >= %{tools_ver}
BuildRequires: kernel-devel = %{kver}


BuildRoot: %{_tmppath}/ocfs2-%{PACKAGE_VERSION}-%{PACKAGE_RELEASE}-root


%description
OCFS2 is the Oracle Cluster Filesystem 2.  This package is compiled for
uniprocessor kernels.

%if %{buildsmp}
%package -n ocfs2-%{kver}smp
Summary: The Oracle Cluster File System 2 for SMP systems.
Group: System Environment/Kernel
Provides: ocfs2 = %{version}
Requires: kernel-smp = %{kver}
Requires: ocfs2-tools >= %{tools_ver}
BuildRequires: kernel-smp-devel = %{kver}
AutoReqProv: no

%description -n ocfs2-%{kver}smp
OCFS2 is the Oracle Cluster Filesystem 2.  This package is compiled for
symmetric multiprocessor kernels.
%endif


%if %{buildhugemem}
%package -n ocfs2-%{kver}hugemem
Summary: The Oracle Cluster File System 2 for huge memory systems.
Group: System Environment/Kernel
Provides: ocfs2 = %{version}
Requires: kernel-hugemem = %{kver}
Requires: ocfs2-tools >= %{tools_ver}
BuildRequires: kernel-hugemem-devel = %{kver}
AutoReqProv: no

%description -n ocfs2-%{kver}hugemem
OCFS2 is the Oracle Cluster Filesystem 2.  This package is compiled for
symmetric multiprocessor kernels.
%endif


%prep
%setup -n ocfs2-%{version}

%if %{buildlargesmp}
%package -n ocfs2-%{kver}largesmp
Summary: The Oracle Cluster File System 2 for large smp systems.
Group: System Environment/Kernel
Provides: ocfs2 = %{version}
Requires: kernel-largesmp = %{kver}
Requires: ocfs2-tools >= %{tools_ver}
BuildRequires: kernel-largesmp-devel = %{kver}
AutoReqProv: no

%description -n ocfs2-%{kver}largesmp
OCFS2 is the Oracle Cluster Filesystem 2.  This package is compiled for
large symmetric multiprocessor kernels.
%endif


%build

local_configure()
{
	./configure					\
		--prefix=%{_prefix}			\
		--exec-prefix=%{_exec_prefix}		\
		--bindir=%{_bindir}			\
		--sbindir=%{_sbindir}			\
		--sysconfdir=%{_sysconfdir}		\
		--datadir=%{_datadir}			\
		--includedir=%{_includedir}             \
		--libdir=%{_libdir}			\
		--libexecdir=%{_libexecdir}		\
		--localstatedir=%{_localstatedir}	\
		--sharedstatedir=%{_sharedstatedir}	\
		--mandir=%{_mandir}			\
		--infodir=%{_infodir}			\
		--enable-debugfs			\
		--with-vendor=el4			\
		--with-vendorkernel="$1"
}

%if %{buildup}
local_configure "%{kver}"

make V=0
make DESTDIR="$RPM_BUILD_ROOT" INSTALL_MOD_PATH='$(DESTDIR)' install 

# 2.6 kbuild can't do this install nicely
EXTRA_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}/extra"
INST_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}/kernel"
mkdir -p "${INST_MODLIB}/fs/ocfs2"
mv "${EXTRA_MODLIB}"/ocfs2*.ko "${INST_MODLIB}/fs/ocfs2/"
mkdir -p "${INST_MODLIB}/fs/configfs"
mv "${EXTRA_MODLIB}"/configfs.ko "${INST_MODLIB}/fs/configfs/"
mkdir -p "${INST_MODLIB}/fs/debugfs"
mv "${EXTRA_MODLIB}"/debugfs.ko "${INST_MODLIB}/fs/debugfs/"
rm "${EXTRA_MODLIB}"/*.ko

make clean
%endif

%if %{buildsmp}
local_configure "%{kver}smp"

make V=0
make DESTDIR="$RPM_BUILD_ROOT" INSTALL_MOD_PATH='$(DESTDIR)' install 

# 2.6 kbuild can't do this install nicely
EXTRA_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}smp/extra"
INST_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}smp/kernel"
mkdir -p "${INST_MODLIB}/fs/ocfs2"
mv "${EXTRA_MODLIB}"/ocfs2*.ko "${INST_MODLIB}/fs/ocfs2/"
mkdir -p "${INST_MODLIB}/fs/configfs"
mv "${EXTRA_MODLIB}"/configfs.ko "${INST_MODLIB}/fs/configfs/"
mkdir -p "${INST_MODLIB}/fs/debugfs"
mv "${EXTRA_MODLIB}"/debugfs.ko "${INST_MODLIB}/fs/debugfs/"
rm "${EXTRA_MODLIB}"/*.ko

make clean
%endif

%if %{buildhugemem}
local_configure "%{kver}hugemem"

make V=0
make DESTDIR="$RPM_BUILD_ROOT" INSTALL_MOD_PATH='$(DESTDIR)' install 

# 2.6 kbuild can't do this install nicely
EXTRA_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}hugemem/extra"
INST_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}hugemem/kernel"
mkdir -p "${INST_MODLIB}/fs/ocfs2"
mv "${EXTRA_MODLIB}"/ocfs2*.ko "${INST_MODLIB}/fs/ocfs2/"
mkdir -p "${INST_MODLIB}/fs/configfs"
mv "${EXTRA_MODLIB}"/configfs.ko "${INST_MODLIB}/fs/configfs/"
mkdir -p "${INST_MODLIB}/fs/debugfs"
mv "${EXTRA_MODLIB}"/debugfs.ko "${INST_MODLIB}/fs/debugfs/"
rm "${EXTRA_MODLIB}"/*.ko

make clean
%endif

%if %{buildlargesmp}
local_configure "%{kver}largesmp"

make V=0
make DESTDIR="$RPM_BUILD_ROOT" INSTALL_MOD_PATH='$(DESTDIR)' install 

# 2.6 kbuild can't do this install nicely
EXTRA_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}largesmp/extra"
INST_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}largesmp/kernel"
mkdir -p "${INST_MODLIB}/fs/ocfs2"
mv "${EXTRA_MODLIB}"/ocfs2*.ko "${INST_MODLIB}/fs/ocfs2/"
mkdir -p "${INST_MODLIB}/fs/configfs"
mv "${EXTRA_MODLIB}"/configfs.ko "${INST_MODLIB}/fs/configfs/"
mkdir -p "${INST_MODLIB}/fs/debugfs"
mv "${EXTRA_MODLIB}"/debugfs.ko "${INST_MODLIB}/fs/debugfs/"
rm "${EXTRA_MODLIB}"/*.ko

make clean
%endif


%clean
rm -rf "$RPM_BUILD_ROOT"


%if %{buildup}
%post
depmod -ae %{kver}

%files
%defattr(-,root,root)
/lib/modules/%{kver}/kernel/fs
%endif

%if %{buildsmp}
%post -n ocfs2-%{kver}smp
depmod -ae %{kver}smp

%files -n ocfs2-%{kver}smp
%defattr(-,root,root)
/lib/modules/%{kver}smp/kernel/fs
%endif


%if %{buildhugemem}
%post -n ocfs2-%{kver}hugemem
depmod -ae %{kver}hugemem

%files -n ocfs2-%{kver}hugemem
%defattr(-,root,root)
/lib/modules/%{kver}hugemem/kernel/fs
%endif

%if %{buildlargesmp}
%post -n ocfs2-%{kver}largesmp
depmod -ae %{kver}largesmp

%files -n ocfs2-%{kver}largesmp
%defattr(-,root,root)
/lib/modules/%{kver}largesmp/kernel/fs
%endif

%changelog
* Thu Jun 22 2006 Sunil Mushran <sunil.mushran@oracle.com>
- Add largesmp

* Mon Jan 24 2004 Manish Singh <manish.singh@oracle.com>
- Initial rpm spec file
